@@ -1,20 +1,19 @@
 #' Retrieve status of the Overpass API
 #'
-#' @param quiet if \code{FALSE} display a status message
-#' @param wait If status is unavailable, wait this long (in s)
+#' @param quiet if `FALSE` display a status message
 #' @return an invisible list of whether the API is available along with the
 #'         text of the message from Overpass and the timestamp of the
 #'         next available slot
 #' @export
-overpass_status <- function (quiet=FALSE, wait=10)
+overpass_status <- function (quiet=FALSE)
 {
     available <- FALSE
     slot_time <- status <- st_type <- NULL
 
     overpass_url <- get_overpass_url ()
     st_type <- 'status'
-    if (grepl ('vi-di', overpass_url) | grepl ('rambler', overpass_url))
-        st_type <- 'timestamp'
+    if (grepl ('vi-di', overpass_url) | grepl ('rambler', overpass_url)) # nocov
+        st_type <- 'timestamp'                                           # nocov
 
     status_url <- gsub ('interpreter', st_type, overpass_url)
 
@@ -24,27 +23,25 @@ overpass_status <- function (quiet=FALSE, wait=10)
         if (!quiet) message (status)
     } else
     {
-        ntrials <- 0
-        while (is.null (status) & ntrials < 10)
-        {
-            ntrials <- ntrials + 1
-            status <- httr::GET (status_url, httr::timeout (100))
-        }
+        status <- httr::RETRY ("GET", status_url, timeout = 100,
+                               times = 10)
         if (!is.null (status))
         {
             status <- httr::content (status, encoding = 'UTF-8')
             if (st_type == 'status')
                 slt <- get_slot_time (status = status, quiet = quiet)
-            else if (st_type == 'timestamp')
-                slt <- get_slot_timestamp (status = status)
+            else if (st_type == 'timestamp')                # nocov
+                slt <- get_slot_timestamp (status = status) # nocov
 
             available <- slt$available
             slot_time <- slt$slot_time
         } else
         {
             # status not even returned so pause the whole shebang for 10 seconds
+            # nocov start
             slot_time <- lubridate::ymd_hms (lubridate::now () + 10)
             slot_time <- lubridate::force_tz (slot_time, tz = Sys.timezone ())
+            # nocov end
         }
     }
 
@@ -60,11 +57,13 @@ get_slot_time <- function (status, quiet)
     if (!quiet) message (status_now)
 
     if (grepl ('after', status_now)) {
+        # nocov start
         available <- FALSE
         slot_time <- lubridate::ymd_hms (gsub ('Slot available after: ',
                                                '', status_now))
         slot_time <- lubridate::force_tz (slot_time,
                                           tz = Sys.timezone ())
+        # nocov end
     } else {
         available <- TRUE
         slot_time <- Sys.time ()
@@ -76,18 +75,20 @@ get_slot_time <- function (status, quiet)
 # For APIs with only timestamps but no status
 get_slot_timestamp <- function (status)
 {
+    # nocov start
     slot_time <- NA
     available <- FALSE
     if (nchar (status) > 1)
         available <- TRUE
 
     list ('available' = available, 'slot_time' = slot_time)
+    # nocov end
 }
 
 #' Check for error issued by overpass server, even though status = 200
 #'
-#' @param doc Character string returned by \code{httr::content} call in
-#' following \code{overpass_query} function.
+#' @param doc Character string returned by `httr::content` call in
+#' following `overpass_query` function.
 #' @param return Nothing; stops execution if error encountered.
 #'
 #' @noRd
@@ -95,6 +96,7 @@ check_for_error <- function (doc)
 {
     # the nchar check uses an arbitrary value to avoid trying to `read_xml()`
     # read data, which would take forever.
+    # nocov start
     if (grepl ("error: ", doc, ignore.case = TRUE) &
         nchar (doc) < 10000)
     {
@@ -109,6 +111,7 @@ check_for_error <- function (doc)
                       xml2::xml_text (docx))
         }
     }
+    # nocov end
 }
 
 
@@ -120,12 +123,12 @@ check_for_error <- function (doc)
 #' @param quiet suppress status messages. OSM Overpass queries may not return
 #'        quickly. The package will display status messages by default showing
 #'        when the query started/completed.  You can disable these messages by
-#'        setting this value to \code{TRUE}.
-#' @param wait if \code{TRUE} and if there is a queue at the Overpass API
+#'        setting this value to `TRUE`.
+#' @param wait if `TRUE` and if there is a queue at the Overpass API
 #'        server, should this function wait and try again at the next available
 #'        slot time or should it throw a an exception?
-#' @param pad_wait if there is a queue and \code{wait} is \code{TRUE}, pad the
-#'        next query start time by \code{pad_wait} seconds (default = 5 seconds).
+#' @param pad_wait if there is a queue and `wait` is `TRUE`, pad the
+#'        next query start time by `pad_wait` seconds (default = 5 seconds).
 #' @param encoding Unless otherwise specified XML documents are assumed to be
 #'        encoded as UTF-8 or UTF-16. If the document is not UTF-8/16, and lacks
 #'        an explicit encoding directive, this allows you to supply a default.
@@ -167,7 +170,7 @@ overpass_query <- function (query, quiet = FALSE, wait = TRUE, pad_wait = 5,
         overpass_url <- 'http://dev.overpass-api.de/test753/interpreter'
 
     if (o_stat$available) {
-        res <- httr::POST (overpass_url, body = query)
+        res <- httr::RETRY ("POST", overpass_url, body = query)
     } else {
         if (wait) {
             wait <- max(0, as.numeric (difftime (o_stat$next_slot, Sys.time(),
